starfish package
================

Subpackages
-----------

.. toctree::

   starfish.ddo
   starfish.job
   starfish.metadata
   starfish.ocean
   starfish.operation

Module contents
---------------

.. automodule:: starfish
   :members:
   :undoc-members:
   :show-inheritance:
